﻿using C1.Web.Mvc;
using C1.Web.Mvc.Serialization;
using FlexGridIntro.Models;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Threading.Tasks;

namespace FlexGridIntro.Controllers
{
    public class HomeController : Controller
    {
        private readonly ILogger<HomeController> _logger;
        public static List<Person> Persons = SampleData.GetData().ToList();

        public HomeController(ILogger<HomeController> logger)
        {
            _logger = logger;
        }
        public ActionResult RemoteBind_Read([C1JsonRequest] CollectionViewRequest<Person> requestData)
        {
            return this.C1Json(CollectionViewHelper.Read(requestData, Persons));
        }

        public ActionResult BatchEditing_Bind([C1JsonRequest] CollectionViewRequest<Person> requestData)
        {
            return this.C1Json(CollectionViewHelper.Read(requestData, Persons));
        }

        public ActionResult GridBatchEdit([C1JsonRequest] CollectionViewBatchEditRequest<Person> requestData)
        {
            return this.C1Json(CollectionViewHelper.BatchEdit(requestData, batchData =>
            {
                var itemresults = new List<CollectionViewItemResult<Person>>();
                string error = string.Empty;
                bool success = true;
                try
                {
                    if (batchData.ItemsCreated != null)
                    {
                        batchData.ItemsCreated.ToList().ForEach(st =>
                        {
                            //_db.Categories.Add(st);
                            Persons.Add(st);
                            itemresults.Add(new CollectionViewItemResult<Person>
                            {
                                Error = "",
                                Success = success,
                                Data = st
                            });
                        });
                    }
                    if (batchData.ItemsDeleted != null)
                    {
                        batchData.ItemsDeleted.ToList().ForEach(category =>
                        {
                            //_db.Categories.Remove(category);
                            Persons.Remove(category);
                            itemresults.Add(new CollectionViewItemResult<Person>
                            {
                                Error = "",
                                Success = success,
                                Data = category
                            });
                        });
                    }
                    if (batchData.ItemsUpdated != null)
                    {
                        batchData.ItemsUpdated.ToList().ForEach(category =>
                        {
                            //_db.Entry(category).State = EntityState.Modified;
                            var index = Persons.FindIndex(x => x.ID == category.ID);
                            Persons[index] = category;
                            itemresults.Add(new CollectionViewItemResult<Person>
                            {
                                Error = "",
                                Success = success,
                                Data = category
                            });
                        });
                    }
                }
                catch (Exception e)
                {
                    //error = GetExceptionMessage(e);
                    error = e.Message;
                    success = false;

                }

                return new CollectionViewResponse<Person>
                {
                    Error = error,
                    Success = success,
                    OperatedItemResults = itemresults
                };
            }, () => Persons));
        }
        public IActionResult Index()
        {
            return View();
        }

        public IActionResult Privacy()
        {
            return View();
        }

        [ResponseCache(Duration = 0, Location = ResponseCacheLocation.None, NoStore = true)]
        public IActionResult Error()
        {
            return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
        }

    }
}
